@@ -46,7 +46,15 @@ describe 'sahara::client' do
         when 'Debian'
           { :client_package_name => 'python3-saharaclient' }
         when 'RedHat'
-          { :client_package_name => 'python-saharaclient' }
+          if facts[:operatingsystem] == 'Fedora'
+            { :client_package_name => 'python3-saharaclient' }
+          else
+            if facts[:operatingsystemmajrelease] > '7'
+              { :client_package_name => 'python3-saharaclient' }
+            else
+              { :client_package_name => 'python-saharaclient' }
+            end
+          end
         end
       end
 
