@@ -42,7 +42,9 @@ describe 'sahara::keystone::authtoken' do
         is_expected.to contain_sahara_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_sahara_config('keystone_authtoken/region_name').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_sahara_config('keystone_authtoken/token_cache_time').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_sahara_config('keystone_authtoken/service_token_roles').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_sahara_config('keystone_authtoken/service_token_roles_required').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_sahara_config('keystone_authtoken/interface').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_sahara_config('trustee/username').with_value('sahara')
         is_expected.to contain_sahara_config('trustee/password').with_value('sahara_password')
         is_expected.to contain_sahara_config('trustee/auth_url').with_value('http://127.0.0.1:5000/')
@@ -89,7 +91,9 @@ describe 'sahara::keystone::authtoken' do
           :manage_memcache_package              => true,
           :region_name                          => 'region2',
           :token_cache_time                     => '301',
+          :service_token_roles                  => ['service'],
           :service_token_roles_required         => false,
+          :interface                            => 'internal',
         })
       end
 
@@ -125,7 +129,9 @@ describe 'sahara::keystone::authtoken' do
         is_expected.to contain_sahara_config('keystone_authtoken/memcached_servers').with_value('memcached01:11211,memcached02:11211')
         is_expected.to contain_sahara_config('keystone_authtoken/region_name').with_value(params[:region_name])
         is_expected.to contain_sahara_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
+        is_expected.to contain_sahara_config('keystone_authtoken/service_token_roles').with_value(params[:service_token_roles])
         is_expected.to contain_sahara_config('keystone_authtoken/service_token_roles_required').with_value(params[:service_token_roles_required])
+        is_expected.to contain_sahara_config('keystone_authtoken/interface').with_value(params[:interface])
         is_expected.to contain_sahara_config('trustee/username').with_value(params[:username])
         is_expected.to contain_sahara_config('trustee/password').with_value(params[:password]).with_secret(true)
         is_expected.to contain_sahara_config('trustee/auth_url').with_value(params[:auth_url])
